# EchoTester

Django app , that record requests that comes to your project then run them whenever you want to determine if things breaks while development (in case you don't have tests written)

## How to use it

### Installation

```bash
pip install django-echo-tester
```

```python
INSTALLED_APPS = [
    ...    
    'echo_tester'
]
```

```python

MIDDLEWARE = [
    ...
    'echo_tester.middleware.TesterMiddleware',
]

```




## Basic use


## Features & How to use
pip install xxx
add to django requirements

python manage.py runecho





## Features && How to use them
## Settings and how to customize them
